@@ -21,21 +21,13 @@ extern crate serde_derive;
 extern crate serde_yaml;
 extern crate uriparse;
 
-mod config;
-mod constants;
 mod errors;
 mod examples;
-mod feelify;
 mod href;
 mod jsonify;
 mod macros;
-mod stringify;
 
-pub use config::{get_configuration, Configuration, ServerConfiguration};
-pub use constants::{DMNTK_COPYRIGHT, DMNTK_EXECUTABLE, DMNTK_NAME, DMNTK_VERSION};
 pub use errors::{DmntkError, Result};
 pub use examples::{EXAMPLE_0001_CTX, EXAMPLE_0001_DTB, EXAMPLE_0002_CTX, EXAMPLE_0002_DTB};
-pub use feelify::Feelify;
 pub use href::{HRef, OptHRef};
 pub use jsonify::Jsonify;
-pub use stringify::Stringify;
